@@ -11,6 +11,12 @@ settings = {
 
     # List of modules to be imported at the start-up.
     "modules": [
+        {
+            # Description, not used by the code.
+            "description": "gis_raster",
+            # The path to the Python file containing the configuration
+            "path_to_the_config": "geobricks_gis_raster.config.config",
+        },
         {
             # Description, not used by the code.
             "description": "Geocoding",
